# MicroStrategy Python API (microstrategy-api)

[![pypi](https://img.shields.io/pypi/v/microstrategy-api.svg)](https://pypi.org/project/microstrategy-api/)
[![license](https://img.shields.io/github/license/arcann/mstr_python_api.svg)](https://github.com/arcann/mstr_python_api/blob/master/license.txt)


Python API library for interacting with MicroStrategy Intelligence Server and/or MicroStrategy Web Server.

This library is not endorsed by, directly affiliated with, maintained, authorized, or sponsored by MicroStragy Incorporated.

Supported MicroStrategy sub-APIs

 - TaskProc API
 - COM API
 - REST API (Work in progress)

## Installation

Install using `pip install -U microstrategy-api` or `conda install microstrategy-api -c conda-forge`.

# Examples

See `examples` folder